==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPivotDateDimensionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebPivotDimensionDescription } from "./WebPivotDimensionDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPivotDateDimensionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPivotDateDimensionDescription, _super);
    function WebPivotDateDimensionDescription() {
        var _this = _super.call(this) || this;
        _this.ah = false;
        _this.ak = null;
        _this.aa = null;
        _this.ae = null;
        _this.ac = null;
        return _this;
    }
    WebPivotDateDimensionDescription.prototype.get_type = function () {
        return "WebPivotDateDimension";
    };
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "enabled", {
        get: function () {
            return this.ah;
        },
        set: function (a) {
            this.ah = a;
            this.e("Enabled");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "dataType", {
        get: function () {
            return this.ak;
        },
        set: function (a) {
            this.ak = a;
            this.e("DataType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "resourceStrings", {
        get: function () {
            return this.aa;
        },
        set: function (a) {
            this.aa = a;
            this.e("ResourceStrings");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "baseDimension", {
        get: function () {
            return this.ae;
        },
        set: function (a) {
            this.ae = a;
            this.e("BaseDimension");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "options", {
        get: function () {
            return this.ac;
        },
        set: function (a) {
            this.ac = a;
            this.e("Options");
        },
        enumerable: true,
        configurable: true
    });
    WebPivotDateDimensionDescription.$t = markType(WebPivotDateDimensionDescription, 'WebPivotDateDimensionDescription', WebPivotDimensionDescription.$);
    WebPivotDateDimensionDescription.__marshalByValue1 = true;
    WebPivotDateDimensionDescription.__marshalByValueAlias1 = "PivotDateDimension";
    return WebPivotDateDimensionDescription;
}(WebPivotDimensionDescription));
export { WebPivotDateDimensionDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPivotDateDimensionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebPivotDimensionDescription } from "./WebPivotDimensionDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPivotDateDimensionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDateDimensionDescription, _super);
    function WebPivotDateDimensionDescription() {
        var _this = _super.call(this) || this;
        _this.ap = false;
        _this.as = null;
        _this.ai = null;
        _this.am = null;
        _this.ak = null;
        _this.at = null;
        return _this;
    }
    WebPivotDateDimensionDescription.prototype.get_type = function () {
        return "WebPivotDateDimension";
    };
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "enabled", {
        get: function () {
            return this.ap;
        },
        set: function (a) {
            this.ap = a;
            this.g("Enabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "dataType", {
        get: function () {
            return this.as;
        },
        set: function (a) {
            this.as = a;
            this.g("DataType");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "resourceStrings", {
        get: function () {
            return this.ai;
        },
        set: function (a) {
            this.ai = a;
            this.g("ResourceStrings");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "baseDimension", {
        get: function () {
            return this.am;
        },
        set: function (a) {
            this.am = a;
            this.g("BaseDimension");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "options", {
        get: function () {
            return this.ak;
        },
        set: function (a) {
            this.ak = a;
            this.g("Options");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotDateDimensionDescription.prototype, "displayName", {
        get: function () {
            return this.at;
        },
        set: function (a) {
            this.at = a;
            this.g("DisplayName");
        },
        enumerable: false,
        configurable: true
    });
    WebPivotDateDimensionDescription.$t = markType(WebPivotDateDimensionDescription, 'WebPivotDateDimensionDescription', WebPivotDimensionDescription.$);
    WebPivotDateDimensionDescription.__marshalByValue1 = true;
    WebPivotDateDimensionDescription.__marshalByValueAlias1 = "PivotDateDimension";
    return WebPivotDateDimensionDescription;
}(WebPivotDimensionDescription));
export { WebPivotDateDimensionDescription };
